/** -------------------------------------------------- 
 * Hochschule f�r Technik Stuttgart 
 * Fachbereich Vermessung , Informatik und Mathematik 
 * Schellingstr . 24 
 * D - 70174 Stuttgart 
 * 
 * Projekt CityDoktor 
 * 
 * Copyright (c) 2011 HFT Stuttgart. All rights reserved. 
 * HFT Stuttgart and its licensors retain all intellectual property and 
 * proprietary rights in and to this software and related documentation. 
 * Any use, reproduction, disclosure, or distribution of this software 
 * and related documentation without an express license agreement from 
 * HFT Stuttgart is strictly prohibited. 
 * 
 * Please refer to the applicable HFT Stuttgart end user license agreement (EULA) 
 * associated with this source code for terms and conditions that govern 
 * your use of this HFT Stuttgart software. 
 * 
 * 11.09.2012
 * bogdahn
 * @author 
 * @version 
 * 
 */
package de.hft.stuttgart.citydoctor2;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import de.hft.stuttgart.citydoctor2.connect.edge.NativeException;

/**
 * @author bogdahn
 * 
 */
public class CppInitializer {

	private static final String SUN_ARCH_DATA_MODEL = "sun.arch.data.model";
	private static Logger logger = LogManager.getLogger(CppInitializer.class);

	private static native boolean initCppLibrary() throws NativeException;

	private static native boolean checkVersions(String jdkVersion) throws NativeException;

	public static synchronized void initCpp() {
		// init CPP JNI Checks
		String dataModel = System.getProperty(SUN_ARCH_DATA_MODEL);
		if (dataModel.equals("64")) {
			// System.loadLibrary( "CityDoctor2CPP-windows-x64-sgd" ); // debug dll
			System.loadLibrary("../CityDoctorHealer/lib/CityDoctor2CPP-windows-x64-s");

//			System.loadLibrary("CityDoctor2CPP-windows-x64-s");
//			System.loadLibrary("lib/libTestHeal");
		} else if (dataModel.equals("32")) {
//    		System.loadLibrary( "CityDoctor2CPP-windows-x86-sgd" ); // debug dll
//			System.loadLibrary("../CityDoctorHealer/lib/CityDoctor2CPP-windows-x86-s");
//			System.loadLibrary("CityDoctor2CPP-windows-x86-s");

			System.err.println("Load native library failed.");
			System.err.println("Unknown architecture: " + dataModel);
			System.err.println("Valid values are: \"64\"");
			System.err.println("No library will be loaded");
		} else {
			System.err.println("Load native library failed.");
			System.err.println("Unknown architecture: " + dataModel);
			System.err.println("Valid values are: \"64\"");
			System.err.println("No library will be loaded");
		}

		try {
			if (initCppLibrary()) {
				// checkVersions(System.getProperty("java.version")); // TODO : checkVersions
				// funktioniert noch nicht!!
			}
		} catch (NativeException ne) {
			System.err.println("Native Exception");
			System.err.println(ne.getType());
			System.err.println(ne.getMessage());
			ne.printStackTrace();
			System.exit(1);
		} catch (IllegalArgumentException e) {
			e.printStackTrace();
			System.exit(1);
		}

	}

	private CppInitializer() {
		// only static utility
	}
}
